@@ -25,14 +25,7 @@
 var NAVTREE =
 [
   [ "EXIF library (libexif) API", "index.html", [
-    [ "The libexif library", "index.html", [
-      [ "General Notes", "index.html#general_notes", null ],
-      [ "Using libexif", "index.html#using_libexif", null ],
-      [ "Primary Data Structures", "index.html#data_structures", null ],
-      [ "String Conventions", "index.html#string_conventions", null ],
-      [ "Memory Management Patterns", "index.html#memory_management", null ],
-      [ "Thread Safety", "index.html#thread_safety", null ]
-    ] ],
+    [ "The libexif library", "index.html", "index" ],
     [ "Deprecated List", "deprecated.html", null ],
     [ "Bug List", "bug.html", null ],
     [ "Data Structures", "annotated.html", [
@@ -60,7 +53,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "__stdint_8h_source.html",
-"exif-tag_8h.html#a1a0ded93d47585f6889eb546915d0f41a93a788ab16801753105b67fde522e93c"
+"exif-tag_8h.html#a1a0ded93d47585f6889eb546915d0f41ad3d1761f519baf37704eaef21d0a1cc0"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
